<?php

namespace Bydedi\Template\Filter;

/**
 * Class SSL
 */

class SSL
{
    /**
     * @var SSL
     */
    private static $instance;
    /**
     * @var array
     */
    private $attributes;

    /**
     * @var array
     */
    private $extensions;


    private function __construct()
    {
        $this->extensions = [];
        $this->attributes = array('src','data-original');
    }

    /**
     * Get instance of Boutique
     *
     * @return null|SSL
     */
    public static function getInstance()
    {
        if (!(self::$instance instanceof self)) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    /**
     * @return bool
     */
    public function isEnabled(){
        return array_key_exists('HTTPS',$_SERVER) && $_SERVER['HTTPS'] != 'off';
    }

    /**
     * @param array $attributes
     */
    public function setAttributes(Array $attributes)
    {
        $this->attributes = $attributes;
    }

    /**
     * @param SSLExtensionInterface $extension
     */
    public function addExtension(SSLExtensionInterface $extension)
    {
        $this->extensions[] = $extension;
    }

    /**
     * @param $string
     *
     * @return mixed
     */
    public function replaceHttpProtocol($string){
        if (self::isEnabled()) {
            if (class_exists('Boutique')){
                $string = $this->replaceBoutiqueDomainInString($string);
            }else {
                $urlnossl = 'http:' . str_replace(array('https:', 'http:'), '', SITE_URL);
                $string = str_replace($urlnossl, str_replace('http:', 'https:', SITE_URL), $string);
            }
            $string = preg_replace('#('.implode('|',$this->attributes).')=([\'"])http:#i', '$1=$2https:', $string);
            foreach ($this->extensions as $e){
                $string = $e->replace($string);
            }
        }
        return $string;
    }

    /**
     * @param $string
     *
     * @return mixed
     */
    protected function replaceBoutiqueDomainInString($string)
    {
        $boutique = new Boutique();
        $boutiques = $boutique->get();
        foreach ($boutiques as $b) {
            $string = str_replace('http://'.$b['boutique_domaine'],'https://'.$b['boutique_domaine'],$string);
        }
        return $string;
    }

    /**
     * @param $output
     * @param $smarty
     *
     * @return mixed
     */
    public function smartyOutputFilter($output, &$smarty)
    {
        return $this->replaceHttpProtocol($output);
    }

    /**
     *
     */
    public function redirect()
    {
        if (!$this->isEnabled() && strpos($_SERVER['HTTP_HOST'],'.dev') === false){
            header('Location: https://'.$_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI'],true,301);
            exit();
        }
    }
}